@@ -31,32 +31,26 @@ def _check_temperature_cols(
         raise ValueError(
             tsutils.error_wrapper(
                 """
-            This evaporation method requires the minimum daily temperature column to be specified with "temp_min_col".""".format(
-                    **locals
-                )
+            This evaporation method requires the minimum daily temperature column to be specified with "temp_min_col"."""
             )
         )
     if temp_max_col is None and temp_max_required is True:
         raise ValueError(
             tsutils.error_wrapper(
                 """
-            This evaporation method requires the maximum daily temperature column to be specified with "temp_max_col".""".format(
-                    **locals
-                )
+            This evaporation method requires the maximum daily temperature column to be specified with "temp_max_col"."""
             )
         )
     if temp_min_col is None or temp_max_col is None:
         raise ValueError(
             tsutils.error_wrapper(
-                """
+                f"""
             If you do not pass a mean daily temperature column in "temp_mean_col"
             you must give both minimum and maximum daily temperatures using
             "temp_min_col" and "temp_max_col".
 
     You gave {temp_min_col} for "temp_min_col" and
-             {temp_max_col} for "temp_max_col". """.format(
-                    **locals
-                )
+             {temp_max_col} for "temp_max_col". """
             )
         )
     return _check_cols(
@@ -69,24 +63,21 @@ def _validate_temperatures(tsd, temp_min_col, temp_max_col):
         if (tsd.tmax < tsd.tmin).any():
             raise ValueError(
                 tsutils.error_wrapper(
-                    """
+                    f"""
                 On the following dates:
 
-        {},
+        {tsd[tsd.tmax < tsd.tmin].index},
 
-        minimum temperature values in column "{}" are greater than or
-        equal to the maximum temperature values in column "{}".""".format(
-                        tsd[tsd.tmax < tsd.tmin].index, temp_min_col, temp_max_col
-                    )
+        minimum temperature values in column "{temp_min_col}" are greater than
+        or equal to the maximum temperature values in column
+        "{temp_max_col}"."""
                 )
             )
 
         warnings.warn(
             tsutils.error_wrapper(
                 """ Since `temp_mean_col` is None, the average daily temperature will be
-estimated by the average of `temp_min_col` and `temp_max_col`""".format(
-                    **locals()
-                )
+estimated by the average of `temp_min_col` and `temp_max_col`"""
             )
         )
         tsd["tmean"] = (tsd.tmin + tsd.tmax) / 2.0
